llm-daemon
----------

Daemon to run llm server. Can be useful when you need a LLM server but don't
want to run it on your own.

- Language Server which requires LLM
- Python script which requires LLM while it's running
